/********************************************************************************/
/*    H   H Y   Y TTTTT EEEEE  CCC       HYTEC ELECTRONICS LTD                  */
/*    H   H  Y Y    T   E     C          5 Cradock Road,                        */
/*    HHHHH   Y     T   EEE   C          Reading, Berks.    Tel: 0118 9757770   */
/*    H   H   Y     T   E     C          RG2 0JT            Fax: 0118 9757566   */
/*    H   H   Y     T   EEEEE  CCC       Web: www.hytec-electronics.co.uk       */
/********************************************************************************/

/********************************************************************************/
/*                                                                              */
/*  Hy8506.h - Header file for device support for the Hytec 8506IP cards        */
/*                                                                              */
/*                               .                                              */
/*                                                                              */
/********************************************************************************/
/*                                                                              */
/*  Revision history: (comment and initial revisions)                           */
/*                                                                              */
/*  vers.       revised         modified by                                     */
/*  -----       -----------     -------------------------                       */
/*  1.1         15-DEC-2010     Jim Chen Hytec Electronics Ltd                  */
/*	                        Driver support for a Hytec Hy8506 IP            	*/
/*			        		module. Initial Version.                        	*/
/*                                                                              */
/********************************************************************************/
 
/* * DRV driver error codes */

#define M_drvLib (1003<<16U)
#define drvError(CODE) (M_drvLib | (CODE))
 
#define S_drv_OK 0                      /* success */
#define S_drv_badParam drvError(1)      /*driver: bad parameter*/
#define S_drv_noMemory drvError(2)      /*driver: no memory*/
#define S_drv_noDevice drvError(3)      /*driver: device not configured*/
#define S_drv_invSigMode drvError(4)    /*driver: signal mode conflicts with device config*/
#define S_drv_cbackChg drvError(5)      /*driver: specified callback differs from previous config*/
#define S_drv_alreadyQd drvError(6)     /*driver: a read request is already queued for the channel*/

#define CONFIGURE	Hy8506Configure
#define REPORT		drvHy8506Report
#define LIST		drvHy8506List
#define INIT		drvHy8506Init

enum cardstate { REMOVED, INSERTED };
enum direction { DIR_IN, DIR_OUT };

/* driver name */

#define DRIVER	"drvHy8506"

#define PROM_MODEL	0x8506
#define PROM_OFFS	0x80
#define CREG_OFFS	0x00
#define RAM_OFFS	0x00

#define CRG_LKC		(CREG_OFFS + 0)
#define CRG_CSR		(CREG_OFFS + 2)
#define CRG_IMR		(CREG_OFFS + 4)
#define CRG_DBR		(CREG_OFFS + 6)
#define CRG_PSR		(CREG_OFFS + 8)
#define CRG_PPR		(CREG_OFFS + A)

#define CSR_ENABLE	1

#define CLOCK_SHIFT	1
#define DEBOUNCE_SHIFT	3
#define SCAN_SHIFT	5
#define DIRECTION_SHIFT	10
#define INTERRUPT_SHIFT	14
#define COS_SHIFT	15

#define MANID		0x00800300
#define MODEL		0x8506
#define REV			0x3301
